%global shortname client

%global submodule_rest zanata-rest-%{shortname}
%global submodule_commands zanata-%{shortname}-commands
%global submodule_cli zanata-cli

Name:           zanata-%{shortname}
Version:        3.3.2
Release:        3%{?dist}
Summary:        Zanata client module

Group:          Development/Tools
License:        LGPLv2+
URL:            https://github.com/zanata/%{name}
Source0:        https://github.com/zanata/%{name}/archive/%{shortname}-%{version}.zip

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  resteasy >= 3.0.1
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.apache.commons:commons-exec)
BuildRequires:  exec-maven-plugin
BuildRequires:  maven-dependency-plugin
BuildRequires:  powermock-junit4
BuildRequires:  powermock-api-mockito
BuildRequires:  powermock-core
BuildRequires:  mvn(org.simpleframework:simple)
BuildRequires:  zanata-parent
BuildRequires:  zanata-api >= 3.3.1
BuildRequires:  xom
BuildRequires:  zanata-common >= 3.3.0
BuildRequires:  args4j >= 2.0.25
BuildRequires:  opencsv
BuildRequires:  openprops
BuildRequires:  jgettext
BuildRequires:  mvn(net.sourceforge.findbugs:annotations)

Requires:       resteasy >= 3.0.1
Requires:       mvn(org.apache.commons:commons-exec)
Requires:       zanata-api
Requires:       zanata-common
Requires:       args4j >= 2.0.25
Requires:       opencsv
Requires:       openprops
Requires:       jgettext
Requires:       xom


%description
Zanata client modules. 
Holds most of Zanata's client code, including Zanata CLI.
It also contains REST stub for interacting with a Zanata server.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       jpackage-utils
Requires:       %{name} = %{version}-%{release}

%description javadoc
This package contains the API documentation for %{shortname}.
This includes submodules:
%{submodule_rest}, %{submodule_commands} and %{submodule_cli}.

%prep
%setup -q -n %{name}-%{shortname}-%{version}
%pom_disable_module zanata-maven-plugin 
%pom_remove_plugin :appassembler-maven-plugin %{submodule_cli}
%pom_remove_plugin :maven-assembly-plugin %{submodule_cli}
# here we replace google findbugs annotations with sourceforge one
%pom_remove_dep com.google.code.findbugs:annotations %{submodule_cli}
%pom_xpath_inject "pom:dependencies" "<dependency><groupId>net.sourceforge.findbugs</groupId><artifactId>annotations</artifactId><version>2.0.2</version></dependency>" %{submodule_cli}
%pom_xpath_inject "pom:dependencies" "<dependency><groupId>com.google.code.findbugs</groupId><artifactId>jsr305</artifactId><version>2.0.1</version></dependency>" %{submodule_cli}

%pom_remove_dep com.google.code.findbugs:annotations %{submodule_commands}
%pom_xpath_inject "pom:dependencies" "<dependency><groupId>net.sourceforge.findbugs</groupId><artifactId>annotations</artifactId><version>2.0.2</version></dependency>" %{submodule_commands}
%pom_xpath_inject "pom:dependencies" "<dependency><groupId>com.google.code.findbugs</groupId><artifactId>jsr305</artifactId><version>2.0.1</version></dependency>" %{submodule_commands}

# simpleframework in fedora is too old
rm %{submodule_cli}/src/test/java/org/zanata/client/HTTPMockContainer.java
rm %{submodule_cli}/src/test/java/org/zanata/client/ClientToServerTest.java


%build
# -Dmaven.local.debug=true
%mvn_build -- -Dmdep.analyze.skip=true -e

# local offline maven can not resolve each module, 
# we have to disable our own module and generate classpath one by one
cd %{submodule_rest}
mvn-rpmbuild dependency:build-classpath -DincludeScope=compile -Dmdep.outputFile=target/%{submodule_rest}-classpath.txt 

cd ..
%pom_remove_dep org.zanata:%{submodule_rest} %{submodule_commands}
cd %{submodule_commands}
mvn-rpmbuild dependency:build-classpath -DincludeScope=compile -Dmdep.outputFile=target/%{submodule_commands}-classpath.txt

cd ..
%pom_remove_dep org.zanata:%{submodule_commands} %{submodule_cli}
cd %{submodule_cli}
mvn-rpmbuild dependency:build-classpath -DincludeScope=compile -Dmdep.outputFile=target/%{submodule_cli}-classpath.txt


%install
%mvn_install

rest_cp=$(cat %{submodule_rest}/target/%{submodule_rest}-classpath.txt)
commands_cp=$(cat %{submodule_commands}/target/%{submodule_commands}-classpath.txt)
cli_cp=$(cat %{submodule_cli}/target/%{submodule_cli}-classpath.txt)

%global CLASSPATH $rest_cp:$commands_cp:$cli_cp

mkdir -p %{buildroot}%{_bindir}

install -d -m 755 %{buildroot}%{_bindir}
# create wrapper script
# adapted from jpackage_script(). 
# We build CLASSPATH at build time and the script won't be able to access it at runtime
############# copied from jpackage_script() ###########################
cat > %{buildroot}%{_bindir}/zanata-cli << ZANATA_CLI
#!/bin/sh
#
# %{name} script
# JPackage Project <http://www.jpackage.org/>

# Source functions library
. %{_javadir}-utils/java-functions

# Source system prefs
if [ -f %{_sysconfdir}/java/%{name}.conf ] ; then
  . %{_sysconfdir}/java/%{name}.conf
fi

# Source user prefs
if [ -f \$HOME/.%{name}rc ] ; then
  . \$HOME/.%{name}rc
fi

# Configuration
MAIN_CLASS=org.zanata.client.ZanataClient
BASE_JARS="%{name} slf4j/log4j12 opencsv"
CLASSPATH=%{CLASSPATH}

# Set parameters
set_jvm
# we have built CLASSPATH above
set_classpath \$BASE_JARS

# Let's start
run "\$@"
ZANATA_CLI

chmod 755 %{buildroot}%{_bindir}/zanata-cli
#################################################################


%files -f .mfiles
%dir %{_javadir}/%{name}
%attr(0755,root,root) %{_bindir}/zanata-cli
%doc README.txt

%files javadoc -f .mfiles-javadoc

%changelog
* Mon Jul 28 2014 Patrick Huang <pahuang@redhat.com> 3.3.2-3
- Add version restriction and fix exec script classpath

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Jun 02 2014 Patrick Huang <pahuang@redhat.com> 3.3.2-1
- Latest upstream version

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 3.3.0-2
- Use Requires: java-headless rebuild (#1067528)

* Thu Jan 09 2014 Patrick Huang <pahuang@redhat.com> 3.3.0-1
- Latest upstream version

* Wed Aug 28 2013 Patrick Huang <pahuang@redhat.com> 3.1.1-1
- Upstream update for newer version of RESTEasy

* Wed Aug 28 2013 Patrick Huang <pahuang@redhat.com> 3.1.0-1
- Upstream update

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu May 16 2013 Patrick Huang <pahuang@redhat.com> 2.2.0-2
- Change license to LGPLv2+

* Fri Mar 1 2013 Patrick Huang <pahuang@redhat.com> 2.2.0-1
- Upstream version update

* Mon Feb 11 2013 Patrick Huang <pahuang@redhat.com> 2.0.1-1
- Initial RPM package
